==> bluer_objects-6.238.1.tar.gz: bluer_objects-6.238.1/bluer_objects/storage/base.py <==
import os
import glob
from typing import Tuple, List

from bluer_objects import objects
from bluer_objects.storage.policies import DownloadPolicy
from bluer_objects.logger import logger


class StorageInterface:
    def clear(
        self,
        do_dryrun: bool = True,
    ) -> bool:
        return True

    def download(
        self,
        object_name: str,
        filename: str = "",
        log: bool = True,
        policy: DownloadPolicy = DownloadPolicy.NONE,
    ) -> bool:
        if log:
            logger.info(
                "{}.download {}{}{}".format(
                    self.__class__.__name__,
                    object_name,
                    f"/{filename}" if filename else "",
                    (
                        ""
                        if policy == DownloadPolicy.NONE
                        else " - policy:{}".format(policy.name.lower())
                    ),
                )
            )

        return True

    def ls(
        self,
        object_name: str,
        where: str = "local",
    ) -> Tuple[bool, List[str]]:
        if where == "local":
            object_path = objects.object_path(
                object_name=object_name,
            )

            return True, sorted(
                [
                    os.path.relpath(filename, start=object_path)
                    for filename in glob.glob(
                        os.path.join(
                            object_path,
                            "**",
                            "*",
                        ),
                        recursive=True,
                    )
                    if os.path.isfile(filename)
                ]
            )

        if where == "cloud":
            logger.error("not implemented")
            return False, []

        logger.error(f"Unknown 'where': {where}")
        return False, []

    def upload(
        self,
        object_name: str,
        filename: str = "",
        public: bool = False,
        zip: bool = False,
        log: bool = True,
    ) -> bool:
        if log:
            logger.info(
                "{}.upload {}{}{}".format(
                    self.__class__.__name__,
                    object_name,
                    ".tar.gz" if zip else f"/{filename}" if filename else "",
                    " [public]" if public else "",
                )
            )

        return True

==> bluer_objects-6.288.1.tar.gz: bluer_objects-6.288.1/bluer_objects/storage/base.py <==
import os
import glob
from typing import Tuple, List

from bluer_objects import objects
from bluer_objects import path
from bluer_objects.storage.policies import DownloadPolicy
from bluer_objects.logger import logger
from bluer_objects.env import ABCLI_OBJECT_ROOT


class StorageInterface:
    def clear(
        self,
        do_dryrun: bool = True,
    ) -> bool:
        return True

    def download(
        self,
        object_name: str,
        filename: str = "",
        log: bool = True,
        policy: DownloadPolicy = DownloadPolicy.NONE,
    ) -> bool:
        if log:
            logger.info(
                "{}.download {}{}{}".format(
                    self.__class__.__name__,
                    object_name,
                    f"/{filename}" if filename else "",
                    (
                        ""
                        if policy == DownloadPolicy.NONE
                        else " - policy:{}".format(policy.name.lower())
                    ),
                )
            )

        return True

    def ls(
        self,
        object_name: str,
        where: str = "local",
    ) -> Tuple[bool, List[str]]:
        if where == "local":
            object_path = objects.object_path(
                object_name=object_name,
            )

            return True, sorted(
                [
                    os.path.relpath(filename, start=object_path)
                    for filename in glob.glob(
                        os.path.join(
                            object_path,
                            "**",
                            "*",
                        ),
                        recursive=True,
                    )
                    if os.path.isfile(filename)
                ]
            )

        if where == "cloud":
            logger.error("not implemented")
            return False, []

        logger.error(f"Unknown 'where': {where}")
        return False, []

    def ls_objects(
        self,
        prefix: str,
        where: str = "local",
    ) -> Tuple[bool, List[str]]:
        if where == "local":
            return True, sorted(
                [
                    os.path.relpath(dirname, start=ABCLI_OBJECT_ROOT)
                    for dirname in glob.glob(
                        os.path.join(
                            ABCLI_OBJECT_ROOT,
                            "*",
                        ),
                        recursive=False,
                    )
                    if not os.path.isfile(dirname)
                    and path.name(dirname).startswith(prefix)
                ]
            )

        if where == "cloud":
            logger.error("not implemented")
            return False, []

        logger.error(f"Unknown 'where': {where}")
        return False, []

    def upload(
        self,
        object_name: str,
        filename: str = "",
        public: bool = False,
        zip: bool = False,
        log: bool = True,
    ) -> bool:
        if log:
            logger.info(
                "{}.upload {}{}{}".format(
                    self.__class__.__name__,
                    object_name,
                    ".tar.gz" if zip else f"/{filename}" if filename else "",
                    " [public]" if public else "",
                )
            )

        return True
